@@ -78,7 +78,7 @@ def plot_umap(embedding_, l, Text, Taxa:None):
 
     TOOLS="hover,crosshair,pan,wheel_zoom,zoom_in,zoom_out,box_zoom,undo,redo,reset,tap,save,box_select,poly_select,lasso_select,"
             
-    if Taxa != None:
+    if Taxa.empty():
         dataE=dict(x=disk_x.tolist(),y=disk_y.tolist(),Color=colors,Name=Text.iloc[:,0].tolist(),Taxa=Taxa.tolist())
         TOOLTIPS=[("Name", "@Name"),("Taxa","@Taxa")]
     else:
